@@ -1,5 +1,6 @@
 mod vis_mod {
     use builder_pattern::Builder;
+    use std::borrow::Cow;
 
     #[allow(dead_code)]
     #[derive(Debug)]
@@ -8,6 +9,7 @@ mod vis_mod {
         B(i32),
     }
 
+    // Private structure
     #[allow(dead_code)]
     #[derive(Builder, Debug)]
     struct PrivateTest<'a, 'b: 'a, T: Sized, U>
@@ -15,44 +17,39 @@ mod vis_mod {
         U: Clone,
     {
         pub a: T,
-        pub b: std::borrow::Cow<'a, U>,
-        #[default(String::from(""))]
-        pub c: String,
-        pub d: &'b &'static i32,
+        pub b: Cow<'a, U>,
+        c: &'b &'static i32,
     }
 
+    // Public structure
     #[derive(Builder, Debug)]
     pub struct PublicTest {
         pub a: i32,
-        #[default(String::from(""))]
-        #[into]
-        pub b: String,
-        #[default(Some(3))]
-        pub c: Option<i32>,
-        #[allow(dead_code)]
-        d: MyEnum,
+        pub b: Option<i32>,
+        c: MyEnum,
     }
 
     #[cfg(test)]
     mod test {
         use super::*;
+        use std::borrow::Cow;
 
         #[test]
         fn private_test() {
             let a = PrivateTest::<i32, String>::new()
                 .a(5)
-                .b(std::borrow::Cow::Owned(String::from("Hello")))
-                .d(&&3)
+                .b(Cow::Owned(String::from("Hello")))
+                .c(&&3)
                 .build();
 
             let b = PrivateTest::<i32, String>::new()
-                .d(&&4)
-                .b(std::borrow::Cow::Owned(String::from("foo")))
+                .c(&&4)
+                .b(Cow::Owned(String::from("foo")))
                 .a(3)
-                .c(String::from("hi"))
                 .build();
 
-            print!("{:?} {:?}", a, b);
+            println!("{:?}", a);
+            println!("{:?}", b);
         }
     }
 }
@@ -62,8 +59,8 @@ use vis_mod::*;
 pub fn main() {
     let t1 = PublicTest::new()
         .a(333)
-        .d(MyEnum::B(5123))
-        .b("Test")
+        .c(MyEnum::B(5123))
+        .b(Some(123))
         .build();
     println!("{:?}", t1);
 }
